@@ -19,6 +19,7 @@
 
 #include <snapd-glib/snapd-auth-data.h>
 #include <snapd-glib/snapd-icon.h>
+#include <snapd-glib/snapd-maintenance.h>
 #include <snapd-glib/snapd-snap.h>
 #include <snapd-glib/snapd-system-information.h>
 #include <snapd-glib/snapd-change.h>
@@ -204,6 +205,8 @@ void                    snapd_client_set_allow_interaction         (SnapdClient
 
 gboolean                snapd_client_get_allow_interaction         (SnapdClient          *client);
 
+SnapdMaintenance       *snapd_client_get_maintenance               (SnapdClient          *client);
+
 SnapdAuthData          *snapd_client_login_sync                    (SnapdClient          *client,
                                                                     const gchar          *email,
                                                                     const gchar          *password,
@@ -313,12 +316,12 @@ GPtrArray              *snapd_client_list_finish                   (SnapdClient
 
 GPtrArray              *snapd_client_get_snaps_sync                (SnapdClient          *client,
                                                                     SnapdGetSnapsFlags    flags,
-                                                                    gchar               **names,
+                                                                    GStrv                 names,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
 void                    snapd_client_get_snaps_async               (SnapdClient          *client,
                                                                     SnapdGetSnapsFlags    flags,
-                                                                    gchar               **names,
+                                                                    GStrv                 names,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
@@ -355,13 +358,28 @@ SnapdSnap              *snapd_client_get_snap_finish               (SnapdClient
 GPtrArray              *snapd_client_get_apps_sync                 (SnapdClient          *client,
                                                                     SnapdGetAppsFlags     flags,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_apps2_sync);
 void                    snapd_client_get_apps_async                (SnapdClient          *client,
                                                                     SnapdGetAppsFlags     flags,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_get_apps2_async);
 GPtrArray              *snapd_client_get_apps_finish               (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_apps2_finish);
+
+GPtrArray              *snapd_client_get_apps2_sync                (SnapdClient          *client,
+                                                                    SnapdGetAppsFlags     flags,
+                                                                    GStrv                 snaps,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_apps2_async               (SnapdClient          *client,
+                                                                    SnapdGetAppsFlags     flags,
+                                                                    GStrv                 snaps,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GPtrArray              *snapd_client_get_apps2_finish              (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
@@ -378,7 +396,7 @@ SnapdIcon              *snapd_client_get_icon_finish               (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
-gchar                 **snapd_client_get_assertions_sync           (SnapdClient          *client,
+GStrv                   snapd_client_get_assertions_sync           (SnapdClient          *client,
                                                                     const gchar          *type,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
@@ -387,16 +405,16 @@ void                    snapd_client_get_assertions_async          (SnapdClient
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
-gchar                 **snapd_client_get_assertions_finish         (SnapdClient          *client,
+GStrv                   snapd_client_get_assertions_finish         (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
 gboolean                snapd_client_add_assertions_sync           (SnapdClient          *client,
-                                                                    gchar               **assertions,
+                                                                    GStrv                 assertions,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
 void                    snapd_client_add_assertions_async          (SnapdClient          *client,
-                                                                    gchar               **assertions,
+                                                                    GStrv                 assertions,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
@@ -609,7 +627,7 @@ gboolean                snapd_client_refresh_finish                (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
-gchar                 **snapd_client_refresh_all_sync              (SnapdClient          *client,
+GStrv                   snapd_client_refresh_all_sync              (SnapdClient          *client,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
@@ -620,7 +638,7 @@ void                    snapd_client_refresh_all_async             (SnapdClient
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
-gchar                 **snapd_client_refresh_all_finish            (SnapdClient          *client,
+GStrv                   snapd_client_refresh_all_finish            (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
@@ -759,14 +777,14 @@ GPtrArray              *snapd_client_get_users_finish              (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
-gchar                 **snapd_client_get_sections_sync             (SnapdClient          *client,
+GStrv                   snapd_client_get_sections_sync             (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
 void                    snapd_client_get_sections_async            (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
-gchar                 **snapd_client_get_sections_finish           (SnapdClient          *client,
+GStrv                   snapd_client_get_sections_finish           (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
@@ -840,14 +858,14 @@ gboolean                snapd_client_prefer_finish                 (SnapdClient
 
 gboolean                snapd_client_enable_aliases_sync           (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error) G_DEPRECATED;
 void                    snapd_client_enable_aliases_async          (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
@@ -859,14 +877,14 @@ gboolean                snapd_client_enable_aliases_finish         (SnapdClient
 
 gboolean                snapd_client_disable_aliases_sync          (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error) G_DEPRECATED;
 void                    snapd_client_disable_aliases_async         (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
@@ -878,14 +896,14 @@ gboolean                snapd_client_disable_aliases_finish        (SnapdClient
 
 gboolean                snapd_client_reset_aliases_sync            (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error) G_DEPRECATED;
 void                    snapd_client_reset_aliases_async           (SnapdClient          *client,
                                                                     const gchar          *snap,
-                                                                    gchar               **aliases,
+                                                                    GStrv                 aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
@@ -897,14 +915,14 @@ gboolean                snapd_client_reset_aliases_finish          (SnapdClient
 
 gboolean                snapd_client_run_snapctl_sync              (SnapdClient          *client,
                                                                     const gchar          *context_id,
-                                                                    gchar               **args,
-                                                                    gchar               **stdout_output,
-                                                                    gchar               **stderr_output,
+                                                                    GStrv                 args,
+                                                                    GStrv                 stdout_output,
+                                                                    GStrv                 stderr_output,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
 void                    snapd_client_run_snapctl_async             (SnapdClient          *client,
                                                                     const gchar          *context_id,
-                                                                    gchar               **args,
+                                                                    GStrv                 args,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
