@@ -60,6 +60,7 @@ G_BEGIN_DECLS
  * @SNAPD_ERROR_REVISION_NOT_AVAILABLE: requested snap revision not available.
  * @SNAPD_ERROR_CHANNEL_NOT_AVAILABLE: requested snap channel not available.
  * @SNAPD_ERROR_NOT_A_SNAP: the given snap or directory does not look like a snap.
+ * @SNAPD_ERROR_DNS_FAILURE: A hostname failed to resolve during the request.
  *
  * Error codes returned by snapd operations.
  *
@@ -96,7 +97,8 @@ typedef enum
     SNAPD_ERROR_NOT_CLASSIC,
     SNAPD_ERROR_REVISION_NOT_AVAILABLE,
     SNAPD_ERROR_CHANNEL_NOT_AVAILABLE,
-    SNAPD_ERROR_NOT_A_SNAP
+    SNAPD_ERROR_NOT_A_SNAP,
+    SNAPD_ERROR_DNS_FAILURE
 } SnapdError;
 
 /**
