@@ -312,6 +312,11 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_NOT_A_SNAP,
                              message);
+    else if (g_strcmp0 (kind, "dns-failure") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_DNS_FAILURE,
+                             message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
@@ -705,6 +710,7 @@ _snapd_json_parse_snap (JsonObject *object, GError **error)
                                     "confinement", confinement,
                                     "epoch", _snapd_json_get_string (c, "epoch", NULL),
                                     "name", _snapd_json_get_string (c, "channel", NULL),
+                                    "released-at", _snapd_json_get_date_time (c, "released-at"),
                                     "revision", _snapd_json_get_string (c, "revision", NULL),
                                     "size", _snapd_json_get_int (c, "size", 0),
                                     "version", _snapd_json_get_string (c, "version", NULL),
